@@ -21,8 +21,8 @@ package org.apache.inlong.agent.utils;
 
 import org.apache.inlong.agent.conf.AgentConfiguration;
 
-import static org.apache.inlong.agent.constants.AgentConstants.DEFAULT_PROMETHEUS_ENABLE;
-import static org.apache.inlong.agent.constants.AgentConstants.PROMETHEUS_ENABLE;
+import static org.apache.inlong.agent.constant.AgentConstants.DEFAULT_PROMETHEUS_ENABLE;
+import static org.apache.inlong.agent.constant.AgentConstants.PROMETHEUS_ENABLE;
 
 public class ConfigUtil {
 
