@@ -17,6 +17,9 @@
 
 package org.apache.inlong.agent.plugin.utils;
 
+import org.apache.inlong.common.metric.MetricRegister;
+import org.powermock.api.mockito.PowerMockito;
+
 import java.io.FileWriter;
 import java.nio.file.Files;
 import java.nio.file.Path;
@@ -25,35 +28,39 @@ import java.nio.file.StandardOpenOption;
 import java.util.ArrayList;
 import java.util.List;
 
+import static org.mockito.ArgumentMatchers.any;
+
 public class TestUtils {
 
     public static String getTestTriggerProfile() {
         return "{\n"
-            + "  \"job\": {\n"
-            + "    \"dir\": {\n"
-            + "      \"path\": \"\",\n"
-            + "      \"pattern\": \"/AgentBaseTestsHelper/"
-            + "org.apache.tubemq.inlong.plugin.fetcher.TestTdmFetcher/test[0-9].dat\"\n"
-            + "    },\n"
-            + "    \"trigger\": \"org.apache.inlong.agent.plugin.trigger.DirectoryTrigger\",\n"
-            + "    \"id\": 1,\n"
-            + "    \"thread\" : {\n"
-            + "\"running\": {\n"
-            + "\"core\": \"4\"\n"
-            + "}\n"
-            + "},  \n"
-            + "    \"op\": \"0\",\n"
-            + "    \"ip\": \"127.0.0.1\",\n"
-            + "    \"name\": \"fileAgentTest\",\n"
-            + "    \"source\": \"org.apache.inlong.agent.plugin.sources.TextFileSource\",\n"
-            + "    \"sink\": \"org.apache.inlong.agent.plugin.sinks.MockSink\",\n"
-            + "    \"channel\": \"org.apache.inlong.agent.plugin.channel.MemoryChannel\",\n"
-            + "    \"standalone\": true,\n"
-            + "    \"additionStr\": \"m=15&file=test\",\n"
-            + "    \"deliveryTime\": \"1231313\",\n"
-            + "    \"splitter\": \"&\"\n"
-            + "  }\n"
-            + "  }";
+                + "  \"job\": {\n"
+                + "    \"fileJob\": {\n"
+                + "      \"additionStr\": \"m=15&file=test\",\n"
+                + "      \"trigger\": \"org.apache.inlong.agent.plugin.trigger.DirectoryTrigger\",\n"
+                + "      \"dir\": {\n"
+                + "        \"path\": \"\",\n"
+                + "        \"pattern\": \"/AgentBaseTestsHelper/"
+                + "org.apache.tubemq.inlong.plugin.fetcher.TestTdmFetcher/test[0-9].dat\"\n"
+                + "      },\n"
+                + "      \"thread\" : {\n"
+                + "\"running\": {\n"
+                + "\"core\": \"4\"\n"
+                + "}\n"
+                + "} \n"
+                + "    },\n"
+                + "    \"id\": 1,\n"
+                + "    \"op\": \"0\",\n"
+                + "    \"ip\": \"127.0.0.1\",\n"
+                + "    \"name\": \"fileAgentTest\",\n"
+                + "    \"source\": \"org.apache.inlong.agent.plugin.sources.TextFileSource\",\n"
+                + "    \"sink\": \"org.apache.inlong.agent.plugin.sinks.MockSink\",\n"
+                + "    \"channel\": \"org.apache.inlong.agent.plugin.channel.MemoryChannel\",\n"
+                + "    \"standalone\": true,\n"
+                + "    \"deliveryTime\": \"1231313\",\n"
+                + "    \"splitter\": \"&\"\n"
+                + "  }\n"
+                + "  }";
     }
 
     public static void createHugeFiles(String fileName, String rootDir, String record) throws Exception {
@@ -67,7 +74,7 @@ public class TestUtils {
     }
 
     public static void createMultipleLineFiles(String fileName, String rootDir,
-        String record, int lineNum) throws Exception {
+            String record, int lineNum) throws Exception {
         final Path hugeFile = Paths.get(rootDir, fileName);
         List<String> beforeList = new ArrayList<>();
         for (int i = 0; i < lineNum; i++) {
@@ -75,4 +82,9 @@ public class TestUtils {
         }
         Files.write(hugeFile, beforeList, StandardOpenOption.CREATE);
     }
+
+    public static void mockMetricRegister() throws Exception {
+        PowerMockito.mockStatic(MetricRegister.class);
+        PowerMockito.doNothing().when(MetricRegister.class, "register", any());
+    }
 }
