@@ -18,9 +18,43 @@
 # specific language governing permissions and limitations
 # under the License.
 #
-cd "$(dirname "$0")"/../
+base_dir=$(
+  cd $(dirname $0)
+  cd ..
+  pwd
+)
+
+error() {
+  local msg=$1
+  local exit_code=$2
+
+  echo "Error: $msg" >&2
+
+  if [ -n "$exit_code" ]; then
+    exit $exit_code
+  fi
+}
+
 prepare_file=conf/server.properties
 if [ ! -f "$prepare_file" ]; then
   touch "$prepare_file"
 fi
-nohup bin/audit-proxy agent --conf conf/ -f conf/audit-proxy.conf -n agent1 --no-reload-conf  > audit-proxy.log 2>&1 &
\ No newline at end of file
+
+MQ_TYPE=pulsar
+if [ -n "$1" ]; then
+  MQ_TYPE=$1
+fi
+
+CONFIG_FILE="audit-proxy-${MQ_TYPE}.conf"
+CONFIG_FILE_WITH_COFING_PATH="conf/${CONFIG_FILE}"
+CONFIG_FILE_WITH_PATH="${base_dir}/conf/${CONFIG_FILE}"
+LOG_DIR="${base_dir}/logs"
+
+if [ ! -d "${LOG_DIR}" ]; then
+  mkdir ${LOG_DIR}
+fi
+if [ -f "$CONFIG_FILE_WITH_PATH" ]; then
+  nohup bash +x bin/audit-proxy agent --conf conf/ -f "${CONFIG_FILE_WITH_COFING_PATH}" -n agent1 --no-reload-conf 1>${LOG_DIR}/proxy.log 2>${LOG_DIR}/proxy-error.log &
+else
+  error "${CONFIG_FILE_WITH_PATH} is not exist! start failed!" 1
+fi
