@@ -19,8 +19,20 @@
 # under the License.
 #
 cd "$(dirname "$0")"/../conf || exit
+basedir="$(pwd)"
 
-for i in {mx.properties,transfer.properties,weight.properties,common.properties,blacklist.properties,groupid_mapping.properties,dc_mapping.properties,topics.properties,tube_switch.properties}
+error() {
+  local msg=$1
+  local exit_code=$2
+
+  echo "Error: $msg" >&2
+
+  if [ -n "$exit_code" ] ; then
+    exit $exit_code
+  fi
+}
+
+for i in {mx.properties,transfer.properties,weight.properties,common.properties,blacklist.properties,groupid_mapping.properties,dc_mapping.properties,topics.properties,tube_switch.properties,third_party_cluster.properties}
 do
   if [ ! -f "$i" ]; then
     touch "$i"
@@ -28,4 +40,18 @@ do
 done
 
 cd .. || exit
-nohup bin/flume-ng agent --conf conf/ -f conf/flume.conf -n agent1 --no-reload-conf  > dataproxy.log 2>&1 &
\ No newline at end of file
+
+MQ_TYPE=pulsar
+if [ -n "$1" ]; then
+  MQ_TYPE=$1
+fi
+
+CONFIG_FILE="dataproxy-${MQ_TYPE}.conf"
+CONFIG_FILE_WITH_COFING_PATH="conf/${CONFIG_FILE}"
+CONFIG_FILE_WITH_PATH="${basedir}/${CONFIG_FILE}"
+
+if [ -f "$CONFIG_FILE_WITH_PATH" ]; then
+  nohup bash +x bin/dataproxy-ng agent --conf conf/ -f "${CONFIG_FILE_WITH_COFING_PATH}" -n agent1 --no-reload-conf  > /dev/null 2>&1 &
+else
+   error "${CONFIG_FILE_WITH_PATH} is not exist! start failed!" 1
+fi
\ No newline at end of file
