@@ -20,4 +20,4 @@
 #
 
 # this program kills the dataProxy
-ps -ef |grep "org.apache.flume.node.Application"|grep "apache-inlong-dataproxy"|grep -v grep|awk '{print $2}'|xargs kill -9
+ps -ef |grep "org.apache.inlong.dataproxy.node.Application"|grep "inlong-dataproxy"|grep -v grep|awk '{print $2}'|xargs kill -9
