@@ -28,7 +28,9 @@ import org.apache.flume.Context;
 import org.apache.flume.Event;
 import org.apache.flume.FlumeException;
 import org.apache.flume.channel.AbstractChannelSelector;
+import org.apache.inlong.dataproxy.consts.AttributeConstants;
 import org.apache.inlong.dataproxy.consts.ConfigConstants;
+import org.apache.inlong.dataproxy.utils.MessageUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -41,11 +43,13 @@ public class FailoverChannelSelector extends AbstractChannelSelector {
     private static final String TRANSFER_CHANNEL = "transfer";
     private static final String FILE_METRIC_CHANNEL = "fileMetric";
     private static final String SLA_METRIC_CHANNEL = "slaMetric";
+    private static final String ORDER_CHANNEL = "order";
 
     private int masterIndex = 0;
     private int slaveIndex = 0;
 
     private final List<Channel> masterChannels = new ArrayList<Channel>();
+    private final List<Channel> orderChannels = new ArrayList<Channel>();
     private final List<Channel> slaveChannels = new ArrayList<Channel>();
     private final List<Channel> transferChannels = new ArrayList<Channel>();
     private final List<Channel> agentFileMetricChannels = new ArrayList<Channel>();
@@ -59,8 +63,15 @@ public class FailoverChannelSelector extends AbstractChannelSelector {
         } else if (event.getHeaders().containsKey(ConfigConstants.FILE_CHECK_DATA)) {
             retChannels.add(agentFileMetricChannels.get(0));
         } else if (event.getHeaders().containsKey(ConfigConstants.SLA_METRIC_DATA)) {
-
             retChannels.add(slaMetricChannels.get(0));
+        } else if (MessageUtils.isSyncSendForOrder(event.getHeaders()
+                .get(AttributeConstants.MESSAGE_SYNC_SEND))) {
+            String partitionKey = event.getHeaders().get(AttributeConstants.MESSAGE_PARTITION_KEY);
+            if (partitionKey == null) {
+                partitionKey = "";
+            }
+            int channelIndex = Math.abs(partitionKey.hashCode()) % orderChannels.size();
+            retChannels.add(orderChannels.get(channelIndex));
         } else {
             retChannels.add(masterChannels.get(masterIndex));
             masterIndex = (masterIndex + 1) % masterChannels.size();
@@ -76,7 +87,6 @@ public class FailoverChannelSelector extends AbstractChannelSelector {
         } else if (event.getHeaders().containsKey(ConfigConstants.FILE_CHECK_DATA)) {
             retChannels.add(agentFileMetricChannels.get(0));
         } else if (event.getHeaders().containsKey(ConfigConstants.SLA_METRIC_DATA)) {
-
             retChannels.add(slaMetricChannels.get(1));
         } else {
             retChannels.add(slaveChannels.get(slaveIndex));
@@ -108,6 +118,7 @@ public class FailoverChannelSelector extends AbstractChannelSelector {
         String transfer = context.getString(TRANSFER_CHANNEL);
         String fileMertic = context.getString(FILE_METRIC_CHANNEL);
         String slaMetric = context.getString(SLA_METRIC_CHANNEL);
+        String orderMetric = context.getString(ORDER_CHANNEL);
         if (StringUtils.isEmpty(masters)) {
             throw new FlumeException("master channel is null!");
         }
@@ -115,6 +126,7 @@ public class FailoverChannelSelector extends AbstractChannelSelector {
         List<String> transferList = splitChannelName(transfer);
         List<String> fileMetricList = splitChannelName(fileMertic);
         List<String> slaMetricList = splitChannelName(slaMetric);
+        List<String> orderMetricList = splitChannelName(orderMetric);
 
         for (Map.Entry<String, Channel> entry : getChannelNameMap().entrySet()) {
             String channelName = entry.getKey();
@@ -127,11 +139,14 @@ public class FailoverChannelSelector extends AbstractChannelSelector {
                 this.agentFileMetricChannels.add(channel);
             } else if (slaMetricList.contains(channelName)) {
                 this.slaMetricChannels.add(channel);
+            } else if (orderMetricList.contains(channelName)) {
+                this.orderChannels.add(channel);
             } else {
                 this.slaveChannels.add(channel);
             }
         }
         LOG.info("masters:" + this.masterChannels);
+        LOG.info("orders:" + this.orderChannels);
         LOG.info("slaves:" + this.slaveChannels);
         LOG.info("transfers:" + this.transferChannels);
         LOG.info("agentFileMetrics:" + this.agentFileMetricChannels);
