@@ -17,25 +17,21 @@
 
 package org.apache.inlong.dataproxy.source;
 
+import io.netty.buffer.ByteBuf;
+import io.netty.channel.Channel;
 import java.util.Map;
 
-import org.jboss.netty.buffer.ChannelBuffer;
-import org.jboss.netty.channel.Channel;
-import org.jboss.netty.channel.MessageEvent;
-
-/**
- * decoder interface definition
- */
 public interface ServiceDecoder {
 
     int HEAD_LENGTH = 4;
 
     /**
      * extract data from buffer and convert it into map.
+     * 
      * @param cb
      * @param channel
-     * @return
-     * @throws
+     * @return Map
+     * @throws Exception
      */
-    Map<String, Object> extractData(ChannelBuffer cb, Channel channel, MessageEvent e) throws Exception;
+    Map<String, Object> extractData(ByteBuf cb, Channel channel) throws Exception;
 }
