@@ -17,17 +17,15 @@
 
 package org.apache.inlong.manager.dao;
 
-import org.junit.runner.RunWith;
+import org.apache.inlong.manager.test.BaseTest;
+import org.springframework.boot.autoconfigure.SpringBootApplication;
 import org.springframework.boot.test.context.SpringBootTest;
 import org.springframework.test.annotation.Rollback;
-import org.springframework.test.context.ActiveProfiles;
-import org.springframework.test.context.junit4.SpringRunner;
 import org.springframework.transaction.annotation.Transactional;
 
-@Rollback
 @Transactional
-@ActiveProfiles(value = "test")
-@RunWith(SpringRunner.class)
-@SpringBootTest
-public abstract class DaoBaseTest {
+@Rollback
+@SpringBootApplication
+@SpringBootTest(classes = DaoBaseTest.class)
+public abstract class DaoBaseTest extends BaseTest {
 }
