@@ -33,17 +33,34 @@ sed -i "s/127.0.0.1:3306/${JDBC_URL}/g" "${conf_file}"
 sed -i "s/datasource.druid.username=.*$/datasource.druid.username=${USERNAME}/g" "${conf_file}"
 sed -i "s/datasource.druid.password=.*$/datasource.druid.password=${PASSWORD}/g" "${conf_file}"
 
-sed -i "s/cluster.tube.manager=.*$/cluster.tube.manager\=${TUBE_MANAGER}/g" "${conf_file}"
-sed -i "s/cluster.tube.master=.*$/cluster.tube.master\=${TUBE_MASTER}/g" "${conf_file}"
-sed -i "s/cluster.tube.clusterId=.*$/cluster.tube.clusterId=${TUBE_CLUSTER_ID}/g" "${conf_file}"
-sed -i "s/cluster.zk.url=.*$/cluster.zk.url=${ZK_URL}/g" "${conf_file}"
-sed -i "s/cluster.zk.root=.*$/cluster.zk.root=${ZK_ROOT}/g" "${conf_file}"
-sed -i "s/sort.appName=.*$/sort.appName=${SORT_APP_NAME}/g" "${conf_file}"
-
 # startup the application
 JAVA_OPTS="-Dspring.profiles.active=${ACTIVE_PROFILE}"
 
+# get plugins from remote address.
+if [[ "${PLUGINS_URL}" =~ ^http* ]]; then
+    # remove the default plugins
+    rm -rf plugins
+    # get the third party plugins
+    wget ${PLUGINS_URL} -O plugins.tar.gz
+    tar -zxvf plugins.tar.gz -C "${file_path}"/
+    rm plugins.tar.gz
+fi
+
+# Whether the database table exists. If it does not exist, initialize the database and skip if it exists.
+if [[ "${JDBC_URL}" =~ (.+):([0-9]+) ]]; then
+  datasource_hostname=${BASH_REMATCH[1]}
+  datasource_port=${BASH_REMATCH[2]}
+
+  select_db_sql="SELECT COUNT(*) FROM information_schema.TABLES WHERE table_schema = 'apache_inlong_manager'"
+  inlong_manager_count=$(mysql -h${datasource_hostname} -P${datasource_port} -u${USERNAME} -p${PASSWORD} -e "${select_db_sql}")
+  inlong_num=$(echo "$inlong_manager_count" | tr -cd "[0-9]")
+  if [ $inlong_num -eq 0 ]; then
+    echo "init apache_inlong_manager database"
+    mysql -h${datasource_hostname} -P${datasource_port} -u${USERNAME} -p${PASSWORD} < sql/apache_inlong_manager.sql
+  fi
+fi
+
 sh "${file_path}"/bin/startup.sh "${JAVA_OPTS}"
 sleep 3
 # keep alive
-tail -F "${file_path}"/log/manager-web.log
+tail -F "${file_path}"/logs/manager-web.log
