@@ -19,28 +19,19 @@ package org.apache.inlong.manager.service.repository;
 
 import com.google.common.base.Splitter;
 import com.google.gson.Gson;
-import java.util.Arrays;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Map.Entry;
-import java.util.Set;
-import java.util.Timer;
-import java.util.TimerTask;
-import javax.annotation.PostConstruct;
 import org.apache.commons.codec.digest.DigestUtils;
-import org.apache.inlong.commons.pojo.dataproxy.CacheClusterObject;
-import org.apache.inlong.commons.pojo.dataproxy.CacheClusterSetObject;
-import org.apache.inlong.commons.pojo.dataproxy.CacheTopicObject;
-import org.apache.inlong.commons.pojo.dataproxy.DataProxyCluster;
-import org.apache.inlong.commons.pojo.dataproxy.DataProxyConfigResponse;
-import org.apache.inlong.commons.pojo.dataproxy.IRepository;
-import org.apache.inlong.commons.pojo.dataproxy.InLongIdObject;
-import org.apache.inlong.commons.pojo.dataproxy.ProxyChannel;
-import org.apache.inlong.commons.pojo.dataproxy.ProxyClusterObject;
-import org.apache.inlong.commons.pojo.dataproxy.ProxySink;
-import org.apache.inlong.commons.pojo.dataproxy.ProxySource;
-import org.apache.inlong.commons.pojo.dataproxy.RepositoryTimerTask;
+import org.apache.inlong.common.pojo.dataproxy.CacheClusterObject;
+import org.apache.inlong.common.pojo.dataproxy.CacheClusterSetObject;
+import org.apache.inlong.common.pojo.dataproxy.CacheTopicObject;
+import org.apache.inlong.common.pojo.dataproxy.DataProxyCluster;
+import org.apache.inlong.common.pojo.dataproxy.DataProxyConfigResponse;
+import org.apache.inlong.common.pojo.dataproxy.IRepository;
+import org.apache.inlong.common.pojo.dataproxy.InLongIdObject;
+import org.apache.inlong.common.pojo.dataproxy.ProxyChannel;
+import org.apache.inlong.common.pojo.dataproxy.ProxyClusterObject;
+import org.apache.inlong.common.pojo.dataproxy.ProxySink;
+import org.apache.inlong.common.pojo.dataproxy.ProxySource;
+import org.apache.inlong.common.pojo.dataproxy.RepositoryTimerTask;
 import org.apache.inlong.manager.common.pojo.dataproxy.DataProxyClusterSet;
 import org.apache.inlong.manager.dao.entity.CacheCluster;
 import org.apache.inlong.manager.dao.entity.CacheClusterExt;
@@ -60,6 +51,17 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Repository;
+import org.springframework.transaction.annotation.Transactional;
+
+import javax.annotation.PostConstruct;
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Map.Entry;
+import java.util.Set;
+import java.util.Timer;
+import java.util.TimerTask;
 
 /**
  * DataProxyConfigRepository
@@ -83,7 +85,7 @@ public class DataProxyConfigRepository implements IRepository {
 
     @PostConstruct
     public void initialize() {
-        LOGGER.info("create repository for {}" + DataProxyConfigRepository.class.getSimpleName());
+        LOGGER.info("create repository for " + DataProxyConfigRepository.class.getSimpleName());
         try {
             this.reloadInterval = DEFAULT_HEARTBEAT_INTERVAL_MS;
             reload();
@@ -96,6 +98,8 @@ public class DataProxyConfigRepository implements IRepository {
     /**
      * reload
      */
+    @Override
+    @Transactional(rollbackFor = Exception.class)
     public void reload() {
         LOGGER.info("start to reload config.");
         List<ClusterSet> setList = clusterSetMapper.selectClusterSet();
@@ -117,7 +121,6 @@ public class DataProxyConfigRepository implements IRepository {
         this.reloadCacheCluster(newClusterSets);
         this.reloadCacheClusterExt(newClusterSets);
         this.reloadCacheTopic(newClusterSets);
-        this.reloadProxyCluster(newClusterSets);
         this.reloadFlumeChannel(newClusterSets);
         this.reloadFlumeChannelExt(newClusterSets);
         this.reloadFlumeSource(newClusterSets);
@@ -126,6 +129,7 @@ public class DataProxyConfigRepository implements IRepository {
         this.reloadFlumeSinkExt(newClusterSets);
         // reload inlongid
         this.reloadInlongId(newClusterSets);
+        this.reloadProxyCluster(newClusterSets);
         this.reloadProxy2Cache(newClusterSets);
         this.generateClusterJson(newClusterSets);
 
@@ -234,6 +238,14 @@ public class DataProxyConfigRepository implements IRepository {
             DataProxyClusterSet setObj = this.getOrCreateDataProxyClusterSet(newClusterSets, setName);
             setObj.getProxyClusterList().add(obj);
             this.proxyClusterMap.put(obj.getName(), obj);
+            // channels
+            obj.getChannels().addAll(setObj.getProxyChannelMap().values());
+            // inlongids
+            obj.getInlongIds().addAll(setObj.getInlongIds());
+            // sinks
+            obj.getSinks().addAll(setObj.getProxySinkMap().values());
+            // sources
+            obj.getSources().addAll(setObj.getProxySourceMap().values());
         }
     }
 
@@ -416,7 +428,7 @@ public class DataProxyConfigRepository implements IRepository {
                 response.setErrCode(DataProxyConfigResponse.SUCC);
                 response.setMd5(md5);
                 response.setData(clusterObj);
-                String jsonResponse = gson.toJson(clusterObj);
+                String jsonResponse = gson.toJson(response);
                 entry.getValue().getProxyConfigJson().put(proxyObj.getName(), jsonResponse);
                 entry.getValue().getMd5Map().put(proxyObj.getName(), md5);
                 entry.getValue().setDefaultConfigJson(jsonResponse);
