@@ -31,6 +31,7 @@ import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
 import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.impl.conn.PoolingHttpClientConnectionManager;
 import org.apache.http.protocol.HttpContext;
+import org.springframework.beans.factory.annotation.Value;
 import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 import org.springframework.context.annotation.Bean;
@@ -51,31 +52,37 @@ public class RestTemplateConfig {
     /**
      * Max total
      */
-    private int maxTotal = 5000;
+    @Value("${common.http-client.maxTotal}")
+    private int maxTotal;
     /**
      * Concurrency
      */
-    private int defaultMaxPerRoute = 2000;
+    @Value("${common.http-client.defaultMaxPerRoute}")
+    private int defaultMaxPerRoute;
 
-    private int validateAfterInactivity = 5000;
+    @Value("${common.http-client.validateAfterInactivity}")
+    private int validateAfterInactivity;
 
     /**
      * Time to connect to the server (successful handshake), timeout throws connect timeout
      */
-    private int connectionTimeout = 3000;
+    @Value("${common.http-client.connectionTimeout}")
+    private int connectionTimeout;
     /**
      * The time for the server to return data (response), timeout throws read timeout
      */
-    private int readTimeout = 10000;
+    @Value("${common.http-client.readTimeout}")
+    private int readTimeout;
     /**
      * Get the timeout time of the connection from the connection pool,
      * and throw ConnectionPoolTimeoutException when timeout
      */
-    private int connectionRequestTimeout = 3000;
+    @Value("${common.http-client.connectionRequestTimeout}")
+    private int connectionRequestTimeout;
 
     @Bean
     public PoolingHttpClientConnectionManager httpClientConnectionManager() {
-        // Support HTTP、HTTPS
+        // Support HTTP, HTTPS
         Registry<ConnectionSocketFactory> registry = RegistryBuilder.<ConnectionSocketFactory>create()
                 .register("http", PlainConnectionSocketFactory.getSocketFactory())
                 .register("https", SSLConnectionSocketFactory.getSocketFactory())
