@@ -17,54 +17,60 @@
 
 package org.apache.inlong.manager.web.controller.openapi;
 
-import java.util.List;
-
+import io.swagger.annotations.Api;
+import io.swagger.annotations.ApiOperation;
+import org.apache.inlong.common.pojo.dataproxy.DataProxyConfig;
+import org.apache.inlong.common.pojo.dataproxy.ThirdPartyClusterDTO;
 import org.apache.inlong.manager.common.beans.Response;
-import org.apache.inlong.manager.common.pojo.dataproxy.DataProxyIpRequest;
-import org.apache.inlong.manager.common.pojo.dataproxy.DataProxyIpResponse;
-import org.apache.inlong.manager.dao.entity.DataProxyConfig;
+import org.apache.inlong.manager.common.pojo.dataproxy.DataProxyResponse;
 import org.apache.inlong.manager.service.core.DataProxyClusterService;
+import org.apache.inlong.manager.service.core.ThirdPartyClusterService;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.web.bind.annotation.GetMapping;
-import org.springframework.web.bind.annotation.PostMapping;
-import org.springframework.web.bind.annotation.RequestBody;
 import org.springframework.web.bind.annotation.RequestMapping;
+import org.springframework.web.bind.annotation.RequestMethod;
 import org.springframework.web.bind.annotation.RequestParam;
 import org.springframework.web.bind.annotation.RestController;
 
-import io.swagger.annotations.Api;
-import io.swagger.annotations.ApiOperation;
+import java.util.List;
 
 @RestController
 @RequestMapping("/openapi/dataproxy")
-@Api(tags = "DataProxy Config")
+@Api(tags = "DataProxy-Config")
 public class DataProxyController {
 
     @Autowired
     private DataProxyClusterService dataProxyClusterService;
+    @Autowired
+    private ThirdPartyClusterService thirdPartyClusterService;
 
-    @PostMapping("/getIpList")
-    @ApiOperation(value = "get data proxy ip list")
-    public Response<List<DataProxyIpResponse>> postIpList(@RequestBody DataProxyIpRequest request) {
-        return Response.success(dataProxyClusterService.getIpList(request));
-    }
-
-    @GetMapping("/getIpList")
-    @ApiOperation(value = "get data proxy ip list")
-    public Response<List<DataProxyIpResponse>> getIpList(@RequestBody DataProxyIpRequest request) {
-        return Response.success(dataProxyClusterService.getIpList(request));
+    @RequestMapping(value = "/getIpList", method = {RequestMethod.GET, RequestMethod.POST})
+    @ApiOperation(value = "Get data proxy ip list by cluster name")
+    public Response<List<DataProxyResponse>> getIpList(@RequestParam(required = false) String clusterName) {
+        return Response.success(thirdPartyClusterService.getIpList(clusterName));
     }
 
     @GetMapping("/getConfig")
-    @ApiOperation(value = "get data proxy config list")
+    @ApiOperation(value = "Get data proxy topic list")
     public Response<List<DataProxyConfig>> getConfig() {
-        return Response.success(dataProxyClusterService.getConfig());
+        return Response.success(thirdPartyClusterService.getConfig());
+    }
+
+    @GetMapping("/getConfig_v2")
+    @ApiOperation(value = "Get data proxy list - including topic")
+    public Response<ThirdPartyClusterDTO> getConfigV2(@RequestParam("clusterName") String clusterName) {
+        ThirdPartyClusterDTO dto = thirdPartyClusterService.getConfigV2(clusterName);
+        if (dto.getMqSet().isEmpty() || dto.getTopicList().isEmpty()) {
+            return Response.fail("failed to get mq config or topics");
+        }
+        return Response.success(dto);
     }
 
     @GetMapping("/getAllConfig")
-    @ApiOperation(value = "get data proxy config")
+    @ApiOperation(value = "Get all proxy config")
     public String getAllConfig(@RequestParam("clusterName") String clusterName, @RequestParam("setName") String setName,
-            @RequestParam("md5") String md5) {
+            @RequestParam(value = "md5", required = false) String md5) {
         return dataProxyClusterService.getAllConfig(clusterName, setName, md5);
     }
+
 }
