@@ -25,8 +25,8 @@ import junit.framework.TestSuite;
 /**
  * Unit test for simple App.
  */
-public class AppTest
-        extends TestCase {
+public class AppTest extends TestCase {
+
     /**
      * Create the test case
      *
@@ -37,6 +37,8 @@ public class AppTest
     }
 
     /**
+     * suite
+     *
      * @return the suite of tests being tested
      */
     public static Test suite() {
@@ -44,9 +46,10 @@ public class AppTest
     }
 
     /**
-     * Rigourous Test :-)
+     * Rigorous Test :-)
      */
     public void testApp() {
         assertTrue(true);
     }
+
 }
