@@ -18,11 +18,14 @@
 package org.apache.inlong.sdk.sort.api;
 
 import org.apache.inlong.sdk.sort.entity.InLongTopic;
+import org.apache.inlong.sdk.sort.impl.decode.MessageDeserializer;
 
 public abstract class InLongTopicFetcher {
 
     protected InLongTopic inLongTopic;
     protected ClientContext context;
+    protected Deserializer deserializer;
+    protected volatile Thread fetchThread;
     protected volatile boolean closed = false;
     protected volatile boolean isStopConsume = false;
     // use for empty topic to sleep
@@ -32,6 +35,7 @@ public abstract class InLongTopicFetcher {
     public InLongTopicFetcher(InLongTopic inLongTopic, ClientContext context) {
         this.inLongTopic = inLongTopic;
         this.context = context;
+        this.deserializer = new MessageDeserializer();
     }
 
     public abstract boolean init(Object client);
