@@ -32,6 +32,9 @@ public class SortClientConfig implements Serializable {
     private ReadCallback callback;
     private int callbackQueueSize = 100;
     private int pulsarReceiveQueueSize = 2000;
+    private int kafkaFetchWaitMs = 5000;
+    private int kafkaFetchSizeBytes = 3 * 1024 * 1024;
+    private int kafkaSocketRecvBufferSize = 5 * 1024 * 1024;
     private Semaphore globalInProgressRequest = new Semaphore(Short.MAX_VALUE, true);
     private String localIp;
     private String appName;
@@ -160,6 +163,30 @@ public class SortClientConfig implements Serializable {
         this.pulsarReceiveQueueSize = pulsarReceiveQueueSize;
     }
 
+    public int getKafkaFetchWaitMs() {
+        return kafkaFetchWaitMs;
+    }
+
+    public void setKafkaFetchWaitMs(int kafkaFetchWaitMs) {
+        this.kafkaFetchWaitMs = kafkaFetchWaitMs;
+    }
+
+    public int getKafkaFetchSizeBytes() {
+        return kafkaFetchSizeBytes;
+    }
+
+    public void setKafkaFetchSizeBytes(int kafkaFetchSizeBytes) {
+        this.kafkaFetchSizeBytes = kafkaFetchSizeBytes;
+    }
+
+    public int getKafkaSocketRecvBufferSize() {
+        return kafkaSocketRecvBufferSize;
+    }
+
+    public void setKafkaSocketRecvBufferSize(int kafkaSocketRecvBufferSize) {
+        this.kafkaSocketRecvBufferSize = kafkaSocketRecvBufferSize;
+    }
+
     public Semaphore getGlobalInProgressRequest() {
         return globalInProgressRequest;
     }
