@@ -31,11 +31,11 @@ import org.apache.commons.lang.math.NumberUtils;
 import org.apache.flume.Channel;
 import org.apache.flume.Context;
 import org.apache.http.HttpHost;
+import org.apache.inlong.common.pojo.sortstandalone.SortTaskConfig;
 import org.apache.inlong.sort.standalone.channel.ProfileEvent;
 import org.apache.inlong.sort.standalone.config.holder.CommonPropertiesHolder;
 import org.apache.inlong.sort.standalone.config.holder.SortClusterConfigHolder;
 import org.apache.inlong.sort.standalone.config.pojo.InlongId;
-import org.apache.inlong.sort.standalone.config.pojo.SortTaskConfig;
 import org.apache.inlong.sort.standalone.metrics.SortMetricItem;
 import org.apache.inlong.sort.standalone.metrics.audit.AuditUtils;
 import org.apache.inlong.sort.standalone.sink.SinkContext;
@@ -137,6 +137,7 @@ public class EsSinkContext extends SinkContext {
                 String uid = InlongId.generateUid(inlongGroupId, inlongStreamId);
                 String jsonIdConfig = JSON.toJSONString(idParam);
                 EsIdConfig idConfig = JSON.parseObject(jsonIdConfig, EsIdConfig.class);
+                idConfig.getFieldList();
                 newIdConfigMap.put(uid, idConfig);
             }
             // change current config
@@ -225,21 +226,6 @@ public class EsSinkContext extends SinkContext {
         metricItem.readFailCount.incrementAndGet();
     }
 
-    /**
-     * fillInlongId
-     * 
-     * @param currentRecord
-     * @param dimensions
-     */
-    public static void fillInlongId(ProfileEvent currentRecord, Map<String, String> dimensions) {
-        String inlongGroupId = currentRecord.getInlongGroupId();
-        inlongGroupId = (StringUtils.isBlank(inlongGroupId)) ? "-" : inlongGroupId;
-        String inlongStreamId = currentRecord.getInlongStreamId();
-        inlongStreamId = (StringUtils.isBlank(inlongStreamId)) ? "-" : inlongStreamId;
-        dimensions.put(SortMetricItem.KEY_INLONG_GROUP_ID, inlongGroupId);
-        dimensions.put(SortMetricItem.KEY_INLONG_STREAM_ID, inlongStreamId);
-    }
-
     /**
      * addSendResultMetric
      * 
