@@ -21,4 +21,12 @@ public class AvroSerializationInfo implements SerializationInfo {
 
     private static final long serialVersionUID = 8446721117598285868L;
 
+    @Override
+    public boolean equals(Object o) {
+        if (this == o) {
+            return true;
+        }
+
+        return o != null && getClass() == o.getClass();
+    }
 }
