@@ -21,4 +21,13 @@ public class CanalSerializationInfo implements SerializationInfo {
 
     private static final long serialVersionUID = 479443152335788151L;
 
+    @Override
+    public boolean equals(Object o) {
+        if (this == o) {
+            return true;
+        }
+
+        return o != null && getClass() == o.getClass();
+    }
+
 }
