@@ -43,6 +43,7 @@ import org.apache.inlong.tubemq.manager.controller.node.request.BatchAddTopicReq
 import org.apache.inlong.tubemq.manager.controller.node.request.CloneBrokersReq;
 import org.apache.inlong.tubemq.manager.controller.node.request.CloneTopicReq;
 import org.apache.inlong.tubemq.manager.controller.node.request.QueryBrokerCfgReq;
+import org.apache.inlong.tubemq.manager.entry.ClusterEntry;
 import org.apache.inlong.tubemq.manager.entry.MasterEntry;
 import org.apache.inlong.tubemq.manager.repository.MasterRepository;
 import org.apache.inlong.tubemq.manager.service.interfaces.MasterService;
@@ -88,7 +89,6 @@ public class NodeServiceImpl implements NodeService {
      *
      * @param masterEntry - node entry
      * @return
-     * @throws IOException
      */
     @Override
     public TubeHttpBrokerInfoList requestBrokerStatus(MasterEntry masterEntry) {
@@ -117,7 +117,7 @@ public class NodeServiceImpl implements NodeService {
      *
      * @param req
      * @return
-     * @throws Exception
+     * @throws Exception exception
      */
     @Override
     public TubeMQResult cloneBrokersWithTopic(CloneBrokersReq req) throws Exception {
@@ -253,7 +253,7 @@ public class NodeServiceImpl implements NodeService {
      * @param needReloadList
      */
     @Override
-    public void handleReloadBroker(MasterEntry masterEntry, List<Integer> needReloadList) {
+    public void handleReloadBroker(MasterEntry masterEntry, List<Integer> needReloadList, ClusterEntry clusterEntry) {
         // reload without exceed max broker.
         if (needReloadList.isEmpty()) {
             return;
@@ -261,7 +261,7 @@ public class NodeServiceImpl implements NodeService {
         int begin = 0;
         int end = 0;
         do {
-            end = Math.min(maxConfigurableBrokerSize + begin, needReloadList.size());
+            end = Math.min(clusterEntry.getReloadBrokerSize() + begin, needReloadList.size());
             List<Integer> brokerIdList = needReloadList.subList(begin, end);
             String brokerStr = StringUtils.join(brokerIdList, ",");
             String url = TubeConst.SCHEMA + masterEntry.getIp() + ":" + masterEntry.getWebPort()
@@ -310,7 +310,7 @@ public class NodeServiceImpl implements NodeService {
      *
      * @param req
      * @return
-     * @throws Exception
+     * @throws Exception exception
      */
     @Override
     public TubeMQResult cloneTopicToBrokers(CloneTopicReq req) throws Exception {
