@@ -17,6 +17,7 @@
 
 package org.apache.inlong.tubemq.manager.service.interfaces;
 
+import java.util.List;
 import java.util.Map;
 
 import org.apache.inlong.tubemq.manager.controller.TubeMQResult;
@@ -67,12 +68,26 @@ public interface MasterService {
      */
     MasterEntry getMasterNode(Long clusterId);
 
+    /**
+     * get master node in one cluster
+     * @param clusterId
+     * @return
+     */
+    List<MasterEntry> getMasterNodes(Long clusterId);
+
+    /**
+     * get master in master ip
+     * @param masterIp
+     * @return
+     */
+    List<MasterEntry> getMasterNodes(String masterIp);
+
     /**
      * use queryBody to generate queryUrl for master query
      *
      * @param queryBody
      * @return
-     * @throws Exception
+     * @throws Exception exception
      */
     String getQueryUrl(Map<String, String> queryBody) throws Exception;
 
@@ -84,4 +99,14 @@ public interface MasterService {
      * @return
      */
     TubeMQResult checkMasterNodeStatus(String masterIp, Integer masterPort);
+
+    String getQueryCountUrl(Integer clusterId, String method);
+
+    /**
+     * delete master by cluster id
+     *
+     * @param clusterId
+     */
+    void deleteMaster(Long clusterId);
+
 }
