@@ -60,15 +60,14 @@ import org.apache.inlong.tubemq.corerpc.service.BrokerWriteService;
 import org.apache.inlong.tubemq.server.Server;
 import org.apache.inlong.tubemq.server.broker.metadata.MetadataManager;
 import org.apache.inlong.tubemq.server.broker.metadata.TopicMetadata;
-import org.apache.inlong.tubemq.server.broker.metrics.BrokerMetricsHolder;
 import org.apache.inlong.tubemq.server.broker.msgstore.MessageStore;
 import org.apache.inlong.tubemq.server.broker.msgstore.MessageStoreManager;
 import org.apache.inlong.tubemq.server.broker.msgstore.disk.GetMessageResult;
 import org.apache.inlong.tubemq.server.broker.nodeinfo.ConsumerNodeInfo;
 import org.apache.inlong.tubemq.server.broker.offset.OffsetRecordInfo;
 import org.apache.inlong.tubemq.server.broker.offset.OffsetService;
-import org.apache.inlong.tubemq.server.broker.stats.CountService;
-import org.apache.inlong.tubemq.server.broker.stats.GroupCountService;
+import org.apache.inlong.tubemq.server.broker.stats.BrokerSrvStatsHolder;
+import org.apache.inlong.tubemq.server.broker.stats.TrafficStatsService;
 import org.apache.inlong.tubemq.server.common.TServerConstants;
 import org.apache.inlong.tubemq.server.common.TStatusConstants;
 import org.apache.inlong.tubemq.server.common.aaaserver.CertificateBrokerHandler;
@@ -78,7 +77,7 @@ import org.apache.inlong.tubemq.server.common.fielddef.WebFieldDef;
 import org.apache.inlong.tubemq.server.common.heartbeat.HeartbeatManager;
 import org.apache.inlong.tubemq.server.common.heartbeat.TimeoutInfo;
 import org.apache.inlong.tubemq.server.common.heartbeat.TimeoutListener;
-import org.apache.inlong.tubemq.server.common.offsetstorage.OffsetStorageInfo;
+import org.apache.inlong.tubemq.server.broker.offset.offsetstorage.OffsetStorageInfo;
 import org.apache.inlong.tubemq.server.common.paramcheck.PBParameterUtils;
 import org.apache.inlong.tubemq.server.common.utils.AppendResult;
 import org.apache.inlong.tubemq.server.common.utils.RowLock;
@@ -107,9 +106,9 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
     // row lock.
     private final RowLock brokerRowLock;
     // statistics of produce.
-    private final CountService putCounterGroup;
+    private final TrafficStatsService putCounterGroup;
     // statistics of consume.
-    private final CountService getCounterGroup;
+    private final TrafficStatsService getCounterGroup;
     // certificate handler.
     private final CertificateBrokerHandler serverAuthHandler;
     // consumer timeout listener.
@@ -126,10 +125,10 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
         this.storeManager = tubeBroker.getStoreManager();
         this.offsetManager = tubeBroker.getOffsetManager();
         this.serverAuthHandler = tubeBroker.getServerAuthHandler();
-        ServiceStatusHolder.setStatisParameters(tubeConfig.getAllowedReadIOExcptCnt(),
+        ServiceStatusHolder.setStatsParameters(tubeConfig.getAllowedReadIOExcptCnt(),
                 tubeConfig.getAllowedWriteIOExcptCnt(), tubeConfig.getIoExcptStatsDurationMs());
-        this.putCounterGroup = new GroupCountService("PutCounterGroup", "Producer", 60 * 1000);
-        this.getCounterGroup = new GroupCountService("GetCounterGroup", "Consumer", 60 * 1000);
+        this.putCounterGroup = new TrafficStatsService("PutCounterGroup", "Producer", 60 * 1000);
+        this.getCounterGroup = new TrafficStatsService("GetCounterGroup", "Consumer", 60 * 1000);
         this.heartbeatManager = new HeartbeatManager();
         this.brokerRowLock =
                 new RowLock("Broker-RowLock", this.tubeConfig.getRowLockWaitDurMs());
@@ -933,7 +932,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
             consumerNodeInfo = new ConsumerNodeInfo(storeManager, reqQryPriorityId,
                     clientId, filterCondSet, reqSessionKey, reqSessionTime, true, partStr);
             if (consumerRegisterMap.put(partStr, consumerNodeInfo) == null) {
-                BrokerMetricsHolder.incConsumerCnt();
+                BrokerSrvStatsHolder.incConsumerOnlineCnt();
             }
             heartbeatManager.regConsumerNode(getHeartbeatNodeId(clientId, partStr), clientId, partStr);
             MessageStore dataStore = null;
@@ -979,7 +978,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
                     heartbeatManager.getConsumerRegMap().get(getHeartbeatNodeId(consumerId, partStr));
             if (timeoutInfo == null || System.currentTimeMillis() >= timeoutInfo.getTimeoutTime()) {
                 if (consumerRegisterMap.remove(partStr) != null) {
-                    BrokerMetricsHolder.decConsumerCnt(true);
+                    BrokerSrvStatsHolder.decConsumerOnlineCnt(true);
                 }
                 strBuffer.append("[Duplicated Register] Remove Invalid Consumer Register ")
                         .append(consumerId).append(TokenConstants.SEGMENT_SEP).append(partStr);
@@ -1045,7 +1044,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
                     .append(request.getPartitionId()).append(" updatedOffset:").append(updatedOffset).toString());
             strBuffer.delete(0, strBuffer.length());
             if (consumerRegisterMap.remove(partStr) != null) {
-                BrokerMetricsHolder.decConsumerCnt(false);
+                BrokerSrvStatsHolder.decConsumerOnlineCnt(false);
             }
             heartbeatManager.unRegConsumerNode(
                     getHeartbeatNodeId(clientId, partStr));
@@ -1333,7 +1332,7 @@ public class BrokerServiceServer implements BrokerReadService, BrokerWriteServic
                     }
                     if (consumerNodeInfo.getConsumerId().equalsIgnoreCase(nodeInfo.getSecondKey())) {
                         if (consumerRegisterMap.remove(nodeInfo.getThirdKey()) != null) {
-                            BrokerMetricsHolder.decConsumerCnt(true);
+                            BrokerSrvStatsHolder.decConsumerOnlineCnt(true);
                         }
                         String[] groupTopicPart =
                                 consumerNodeInfo.getPartStr().split(TokenConstants.ATTR_SEP);
