@@ -101,7 +101,18 @@ public enum CliArgDef {
             "Return http's methods."),
     FILEPATH("f", "file",
             "String: file path.",
-            "File path.");
+            "File path."),
+    METAFILEPATH("path", "meta-file-path",
+            "String: backup or recovery file path.",
+            "File path to backup or restore metadata."
+                    + " Defaults value is the current path where the program is running."),
+    OPERATIONTYPE("type", "operation-type",
+            "String: operation type, include [backup, recovery]",
+            "Types of operations on metadata"),
+    AUTHTOKEN("token", "auth-token",
+            "String: API operation authorization code",
+            "API operation authorization code,"
+                    + " required when adding or modifying, optional when querying");
 
     CliArgDef(String opt, String longOpt, String optDesc) {
         this(opt, longOpt, false, "", optDesc);
