@@ -45,7 +45,7 @@ import org.apache.inlong.tubemq.server.common.statusdef.TopicStatus;
 import org.apache.inlong.tubemq.server.master.TMaster;
 import org.apache.inlong.tubemq.server.master.bdbstore.bdbentitys.BdbBrokerConfEntity;
 import org.apache.inlong.tubemq.server.master.metamanage.DataOpErrCode;
-import org.apache.inlong.tubemq.server.master.metamanage.MetaDataManager;
+import org.apache.inlong.tubemq.server.master.metamanage.MetaDataService;
 import org.apache.inlong.tubemq.server.master.metamanage.metastore.dao.entity.BaseEntity;
 import org.apache.inlong.tubemq.server.master.metamanage.metastore.dao.entity.TopicPropGroup;
 
@@ -371,29 +371,30 @@ public class WebParameterUtils {
     }
 
     /**
-     * Compare whether the configured port values conflict
+     * Compare the configured ports for conflicts
      *
      * @param brokerPort     broker port
      * @param brokerTlsPort  broker tls port
      * @param brokerWebPort  broker web port
-     * @param sBuffer        string buffer
+     * @param strBuff        string buffer
      * @param result     check result of parameter value
-     * @return process result
+     * @return   true for valid, false for invalid
      */
-    public static boolean isLegallyPortValueSet(int brokerPort, int brokerTlsPort,
-                                                int brokerWebPort, StringBuilder sBuffer,
-                                                ProcessResult result) {
-        result.setSuccResult(null);
+    public static boolean isValidPortsSet(int brokerPort, int brokerTlsPort,
+                                          int brokerWebPort, StringBuilder strBuff,
+                                          ProcessResult result) {
         if (brokerPort == brokerWebPort || brokerTlsPort == brokerWebPort) {
             result.setFailResult(DataOpErrCode.DERR_ILLEGAL_VALUE.getCode(),
-                    sBuffer.append("Illegal port value configuration, the value of ")
+                    strBuff.append(DataOpErrCode.DERR_CONFLICT_VALUE.getDescription())
+                            .append(", the value of ")
                             .append(WebFieldDef.BROKERPORT.name).append(" or ")
                             .append(WebFieldDef.BROKERTLSPORT.name)
                             .append(" cannot be the same as the value of")
                             .append(WebFieldDef.BROKERWEBPORT.name).toString());
-            sBuffer.delete(0, sBuffer.length());
+            strBuff.delete(0, strBuff.length());
+            return result.isSuccess();
         }
-        return result.isSuccess();
+        return true;
     }
 
     /**
@@ -809,7 +810,7 @@ public class WebParameterUtils {
      * Get and valid topicName value
      *
      * @param req        Http Servlet Request
-     * @param confManager  configure manager
+     * @param defMetaDataService  configure manager
      * @param required   a boolean value represent whether the parameter is must required
      * @param defValue   a default value returned if the field not exist
      * @param sBuffer     string buffer
@@ -817,7 +818,7 @@ public class WebParameterUtils {
      * @return process result
      */
     public static boolean getAndValidTopicNameInfo(HttpServletRequest req,
-                                                   MetaDataManager confManager,
+                                                   MetaDataService defMetaDataService,
                                                    boolean required,
                                                    String defValue,
                                                    StringBuilder sBuffer,
@@ -828,7 +829,7 @@ public class WebParameterUtils {
         }
         Set<String> topicNameSet = (Set<String>) result.getRetData();
         Set<String> existedTopicSet =
-                confManager.getTotalConfiguredTopicNames();
+                defMetaDataService.getTotalConfiguredTopicNames();
         for (String topic : topicNameSet) {
             if (!existedTopicSet.contains(topic)) {
                 result.setFailResult(sBuffer.append(WebFieldDef.COMPSTOPICNAME.name)
@@ -1224,9 +1225,9 @@ public class WebParameterUtils {
      * @param fieldDef     the parameter field definition
      * @param paramValue   the parameter value
      * @param hasMinVal    whether there is a minimum
-     * param minValue      the parameter min value
+     * @param minValue      the parameter min value
      * @param hasMaxVal    whether there is a maximum
-     * param maxValue      the parameter max value
+     * @param maxValue      the parameter max value
      * @param sBuffer      string buffer
      * @param result   process result
      * @return check result for string value of parameter
