@@ -24,8 +24,8 @@ import java.util.Date;
 import org.apache.commons.lang.builder.ToStringBuilder;
 import org.apache.inlong.tubemq.corebase.TBaseConstants;
 import org.apache.inlong.tubemq.corebase.TokenConstants;
+import org.apache.inlong.tubemq.corebase.utils.DateTimeConvertUtils;
 import org.apache.inlong.tubemq.corebase.utils.TStringUtils;
-import org.apache.inlong.tubemq.server.common.utils.WebParameterUtils;
 import org.apache.inlong.tubemq.server.master.metamanage.metastore.TStoreConstants;
 
 @Entity
@@ -146,7 +146,7 @@ public class BdbBlackGroupEntity implements Serializable {
                 .append("\",\"attributes\":\"").append(attributes)
                 .append("\",\"createUser\":\"").append(createUser)
                 .append("\",\"createDate\":\"")
-                .append(WebParameterUtils.date2yyyyMMddHHmmss(createDate))
+                .append(DateTimeConvertUtils.date2yyyyMMddHHmmss(createDate))
                 .append("\"}");
     }
 
